@@ -1,7 +1,9 @@
 package Sah::Schemas::Collection;
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-03-02'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DIST = 'Sah-Schemas-Collection'; # DIST
+our $VERSION = '0.003'; # VERSION
 
 1;
 # ABSTRACT: Various Sah collection (array/hash) schemas
@@ -18,7 +20,7 @@ Sah::Schemas::Collection - Various Sah collection (array/hash) schemas
 
 =head1 VERSION
 
-This document describes version 0.002 of Sah::Schemas::Collection (from Perl distribution Sah-Schemas-Collection), released on 2020-03-02.
+This document describes version 0.003 of Sah::Schemas::Collection (from Perl distribution Sah-Schemas-Collection), released on 2020-03-02.
 
 =head1 SAH SCHEMAS
 
